diff options
| author | Piotr Milewski <vurmil@gmail.com> | 2025-02-12 13:53:14 +0100 |
|---|---|---|
| committer | Michal Nasiadka <mnasiadka@gmail.com> | 2025-03-24 12:37:43 +0000 |
| commit | 47a6ad020d7a52b14106938e03e27d65280999cb (patch) | |
| tree | d9d7a4c3544502220acad2bf0c064b8bd899550d /doc | |
| parent | d332efe2101b7806cff992d304ba5d5a4ec51c61 (diff) | |
| download | kolla-47a6ad020d7a52b14106938e03e27d65280999cb.tar.gz kolla-47a6ad020d7a52b14106938e03e27d65280999cb.zip | |
Opensearch and opensearch-dashboard image size reduction
When building an image, the RUN command grants
permissions which causes the previous layer
to be copied.
During the test, the image was reduced from 2.84GB to 1.57GB
Closes-Bug: #2104007
Change-Id: I7d2367d4c277287f4db2885f5720a35d934f94b7
Diffstat (limited to 'doc')
0 files changed, 0 insertions, 0 deletions
